@@ -159,8 +159,6 @@ class CompVisTestCase(unittest.TestCase):
             self.assertIn(computer_choice, ['Rock', 'Paper', 'Scissors'], 'The function `get_computer_choice` should `return` a string with the value `Rock`, `Paper` or `Scissors`.')
         except TimeoutError:
             self.fail(' : Something went wrong when running the function `get_computer_choice`. Make sure you have defined the function correctly in the manual_rps.py file and that it does not have any infinite loop.')
-        except:
-            self.fail(' : Something went wrong when running the function `get_computer_choice`. Make sure you have defined the function correctly in the manual_rps.py file and that it does not accept any parameter. If you have defined the choices as a list of strings, make sure you have defined this variable inside the function.')
 
         try:
             with patch('builtins.input', return_value='Rock'):
@@ -168,8 +166,6 @@ class CompVisTestCase(unittest.TestCase):
             self.assertEqual(user_choice, 'Rock', 'The function `get_user_choice` should ask the user for an input and then `return` that input.')
         except TimeoutError:
             self.fail(' : Something went wrong when running the function `get_user_choice`. Make sure you have defined the function correctly in the manual_rps.py file and that it does not have any infinite loop.')
-        except:
-            self.fail(' : Something went wrong when running the function `get_user_choice`. Make sure you have defined the function correctly in the manual_rps.py file and that it does not accept any parameter.')
 
     @timeout_decorator.timeout(10, timeout_exception=TimeoutError)
     def test_get_winner(self):
@@ -179,24 +175,19 @@ class CompVisTestCase(unittest.TestCase):
             with redirect_stdout(f):
                 get_winner('Rock', 'Rock')
                 message = f.getvalue()
-            first_line = message.split('\n')[0]
-            self.assertEqual(first_line, 'It is a tie!', 'The function `get_winner` should print `It is a tie!` if the user and the computer have the same choice. Also, the choices you used in the if-elif-else statement should be `Rock`, `Paper` and `Scissors`')
+            self.assertIn('It is a tie!', message, 'The function `get_winner` should print `It is a tie!` if the user and the computer have the same choice. Also, the choices you used in the if-elif-else statement should be `Rock`, `Paper` and `Scissors`')
             f = io.StringIO()
             with redirect_stdout(f):
                 get_winner('Paper', 'Rock')
                 message = f.getvalue()
-            first_line = message.split('\n')[0]
-            self.assertEqual(first_line, 'You lost', 'The function `get_winner` should print `You lost` if the computer wins the game. If you think you did everything correctly, make sure that the first argument of your `get_winner` function is `computer_choice` and the second argument is `user_choice`. Also, the choices you used in the if-elif-else statement should be `Rock`, `Paper` and `Scissors`')
+            self.assertIn('You lost', message, 'The function `get_winner` should print `You lost` if the computer wins the game. If you think you did everything correctly, make sure that the first argument of your `get_winner` function is `computer_choice` and the second argument is `user_choice`. Also, the choices you used in the if-elif-else statement should be `Rock`, `Paper` and `Scissors`')
             f = io.StringIO()
             with redirect_stdout(f):
                 get_winner('Paper', 'Scissors')
                 message = f.getvalue()
-            first_line = message.split('\n')[0]
-            self.assertEqual(first_line, 'You won!', 'The function `get_winner` should print `You won` if you win the game. If you think you did everything correctly, make sure that the first argument of your `get_winner` function is `computer_choice` and the second argument is `user_choice`. Also, the choices you used in the if-elif-else statement should be `Rock`, `Paper` and `Scissors`')
+            self.assertIn('You won!', message, 'The function `get_winner` should print `You won!` if you win the game. If you think you did everything correctly, make sure that the first argument of your `get_winner` function is `computer_choice` and the second argument is `user_choice`. Also, the choices you used in the if-elif-else statement should be `Rock`, `Paper` and `Scissors`')
         except TimeoutError:
             self.fail(' : Something went wrong when running the function `get_winner`. Make sure you have defined the function correctly in the manual_rps.py file and that it does not have any infinite loop.')
-        except:
-            self.fail(' : Something went wrong when running the function `get_winner`. Make sure you have defined the function correctly in the manual_rps.py file and that it accepts two parameters: `computer_choice` and `user_choice` in that order. Also, the choices you used in the if-elif-else statement should be `Rock`, `Paper` and `Scissors`.')
 
     def test_play_game(self):
         self.assertIn('play', self.function_names, 'You should have a function named `play` in your manual_rps.py file. It doesn\'t need to accept any parameter.')
